==> pw-iso20022-SRU2022-9.3.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/ReuseDataReport3Choice.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Information on reusability of previously submitted data.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ReuseDataReport3Choice", propOrder = {
    "_new",
    "err",
    "crrctn",
    "collReuseUpd"
})
public class ReuseDataReport3Choice {

    @XmlElement(name = "New")
    protected ReuseDataReportNew3 _new;
    @XmlElement(name = "Err")
    protected ReuseDataReportError3 err;
    @XmlElement(name = "Crrctn")
    protected ReuseDataReportCorrection7 crrctn;
    @XmlElement(name = "CollReuseUpd")
    protected ReuseDataReportCorrection7 collReuseUpd;

    /**
     * Gets the value of the new property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportNew3 }
     *     
     */
    public ReuseDataReportNew3 getNew() {
        return _new;
    }

    /**
     * Sets the value of the new property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportNew3 }
     *     
     */
    public ReuseDataReport3Choice setNew(ReuseDataReportNew3 value) {
        this._new = value;
        return this;
    }

    /**
     * Gets the value of the err property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportError3 }
     *     
     */
    public ReuseDataReportError3 getErr() {
        return err;
    }

    /**
     * Sets the value of the err property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportError3 }
     *     
     */
    public ReuseDataReport3Choice setErr(ReuseDataReportError3 value) {
        this.err = value;
        return this;
    }

    /**
     * Gets the value of the crrctn property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReportCorrection7 getCrrctn() {
        return crrctn;
    }

    /**
     * Sets the value of the crrctn property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReport3Choice setCrrctn(ReuseDataReportCorrection7 value) {
        this.crrctn = value;
        return this;
    }

    /**
     * Gets the value of the collReuseUpd property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReportCorrection7 getCollReuseUpd() {
        return collReuseUpd;
    }

    /**
     * Sets the value of the collReuseUpd property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReport3Choice setCollReuseUpd(ReuseDataReportCorrection7 value) {
        this.collReuseUpd = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/ReuseDataReport3Choice.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Information on reusability of previously submitted data.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ReuseDataReport3Choice", propOrder = {
    "_new",
    "err",
    "crrctn",
    "collReuseUpd"
})
public class ReuseDataReport3Choice {

    @XmlElement(name = "New")
    protected ReuseDataReportNew3 _new;
    @XmlElement(name = "Err")
    protected ReuseDataReportError3 err;
    @XmlElement(name = "Crrctn")
    protected ReuseDataReportCorrection7 crrctn;
    @XmlElement(name = "CollReuseUpd")
    protected ReuseDataReportCorrection7 collReuseUpd;

    /**
     * Gets the value of the new property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportNew3 }
     *     
     */
    public ReuseDataReportNew3 getNew() {
        return _new;
    }

    /**
     * Sets the value of the new property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportNew3 }
     *     
     */
    public ReuseDataReport3Choice setNew(ReuseDataReportNew3 value) {
        this._new = value;
        return this;
    }

    /**
     * Gets the value of the err property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportError3 }
     *     
     */
    public ReuseDataReportError3 getErr() {
        return err;
    }

    /**
     * Sets the value of the err property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportError3 }
     *     
     */
    public ReuseDataReport3Choice setErr(ReuseDataReportError3 value) {
        this.err = value;
        return this;
    }

    /**
     * Gets the value of the crrctn property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReportCorrection7 getCrrctn() {
        return crrctn;
    }

    /**
     * Sets the value of the crrctn property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReport3Choice setCrrctn(ReuseDataReportCorrection7 value) {
        this.crrctn = value;
        return this;
    }

    /**
     * Gets the value of the collReuseUpd property.
     * 
     * @return
     *     possible object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReportCorrection7 getCollReuseUpd() {
        return collReuseUpd;
    }

    /**
     * Sets the value of the collReuseUpd property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReuseDataReportCorrection7 }
     *     
     */
    public ReuseDataReport3Choice setCollReuseUpd(ReuseDataReportCorrection7 value) {
        this.collReuseUpd = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
